@@ -12,7 +12,7 @@ use URI::Template;
 use JSON ();
 use Carp;
 
-our $VERSION = v0.12.4;
+our $VERSION = v0.13.0;
 
 sub new {
     my($class, %params) = @_;
@@ -276,14 +276,14 @@ WWW::PGXN - Interface to PGXN mirrors and the PGXN API
 
 =head1 Synopsis
 
-  my $pgxn = WWW::PGXN->new( url => 'http://api.pgxn.org/' );
+  my $pgxn = WWW::PGXN->new( url => 'https://api.pgxn.org/' );
   my $dist = $pgxn->get_distribution('pgTAP');
   $dist->download_to('.');
 
 =head1 Description
 
 This module provide a simple Perl interface over the the L<PGXN
-API|http://github.com/pgxn/pgxn-api/wiki>. It also works with any PGXN mirror
+API|https://github.com/pgxn/pgxn-api/wiki>. It also works with any PGXN mirror
 server. It provides an interface for finding distributions, extensions, users,
 and tags, as well as for accessing documentation, lists of users, and the
 full-text search interface. WWW::PGXN is designed to make it dead simple for
@@ -291,13 +291,13 @@ applications such as web apps and command-line clients to get the data they
 need from a PGXN mirror with a minimum of hassle, including via the file
 system, if there is a local mirror.
 
-L<PGXN|http://pgxn.org> is a L<CPAN|http://cpan.org>-inspired network for
-distributing extensions for the L<PostgreSQL RDBMS|http://www.postgresql.org>.
+L<PGXN|https://pgxn.org> is a L<CPAN|https://cpan.org>-inspired network for
+distributing extensions for the L<PostgreSQL RDBMS|https://www.postgresql.org>.
 All of the infrastructure tools, however, have been designed to be used to
 create networks for distributing any kind of release distributions and for
 providing a lightweight static file JSON REST API. As such, WWW::PGXN should
 work with any mirror that gets its data from a
-L<PGXN::Manager|http://github.com/theory/pgxn-manager>-managed master server,
+L<PGXN::Manager|https://github.com/theory/pgxn-manager>-managed master server,
 and with any L<PGXN::API>-powered server.
 
 =head1 Interface
@@ -306,7 +306,7 @@ and with any L<PGXN::API>-powered server.
 
 =head3 C<new>
 
-  my $pgxn = WWW::PGXN->new(url => 'http://api.pgxn.org/');
+  my $pgxn = WWW::PGXN->new(url => 'https://api.pgxn.org/');
 
 Construct a new WWW::PGXN object. The only required attribute is C<url>. The
 supported parameters are:
@@ -590,7 +590,7 @@ Returns the path for an tag metadata file.
 
 =over
 
-=item * L<PGXN|http://pgxn.org/>
+=item * L<PGXN|https://pgxn.org/>
 
 The PostgreSQL Extension Network, the reference implementation of the PGXN
 infrastructure.
@@ -599,12 +599,12 @@ infrastructure.
 
 Creates and serves a PGXN API implementation from a PGXN mirror.
 
-=item * L<API Documentation|http://github.com/theory/pgxn-api>
+=item * L<API Documentation|https://github.com/theory/pgxn-api>
 
 Comprehensive documentation of the REST API provided by L<PGXN::API> and
 consumed by WWW::PGXN.
 
-=item * L<PGXN::Manager|http://github.com/theory/pgxn-manager>
+=item * L<PGXN::Manager|https://github.com/theory/pgxn-manager>
 
 Server for managing a master PGXN mirror and allowing users to upload
 distributions to it.
@@ -613,13 +613,10 @@ distributions to it.
 
 =head1 Support
 
-This module is stored in an open L<GitHub
-repository|http://github.com/theory/www-pgxn/>. Feel free to fork and
-contribute!
-
-Please file bug reports via L<GitHub
-Issues|http://github.com/theory/www-pgxn/issues/> or by sending mail to
-L<bug-WWW-PGXN@rt.cpan.org|mailto:bug-WWW-PGXN@rt.cpan.org>.
+This module is stored in a public
+L<GitHub repository|https://github.com/theory/www-pgxn/>. Feel free to fork
+and contribute! Please file bug reports via
+L<GitHub Issues|https://github.com/theory/www-pgxn/issues/>
 
 =head1 Author
 
@@ -627,7 +624,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2011 David E. Wheeler. Some Rights Reserved.
+Copyright (c) 2011-2024 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
